- y
A vector of \(N\) spatio-temporal observations to decorrelate.
- st
A three-column matrix specifying the spatial locations and observation
times of the observations to decorrelate.
- y0
A vector of \(N_0\) in-control (IC) spatio-temporal observations from
which the IC spatio-temporal mean and covariance functions can be estimated
via spte_meanest and spte_covest.
- st0
A three-column matrix specifying the spatial locations and times for all
the spatio-temporal observations in y0.
- T
The period of the spatio-temporal mean and covariance. Default value is 1.
- ht
The temporal kernel bandwidth ht; default is NULL, and it will
be chosen by the modified cross-validation mod_cv if ht=NULL.
- hs
The spatial kernel bandwidth hs; default is NULL, and it will
be chosen by the function mod_cv if hs=NULL.
- gt
The temporal kernel bandwidth gt; default is NULL, and it will
be chosen by minimizing the mean squared prediction error via cv_mspe
if gt=NULL.
- gs
The spatial kernel bandwidth gs; default is NULL, and it will
be chosen by the function cv_mspe if gs=NULL.