The bandwidths (ht, hs) used in the estimation
procedure.
stE
Same as the one in the arguments.
muhat
The estimated mean values at the spatial locations and times
specified by stE.
Arguments
y
A vector of spatio-temporal observations.
st
A three-column matrix specifying the spatial locations and times for all the
spatio-temporal observations in y.
ht
The temporal kernel bandwidth ht; default is NULL and it will
be chosen by the modified cross-validation mod_cv if ht=NULL.
hs
The spatial kernel bandwidth hs; default is NULL, and it will
be chosen by the function mod_cv if hs=NULL.
cor
A logical indicator where cor=FALSE implies that the covariance is not
taken into account and the local linear kernel smoothing procedure is used for
estimating the mean function (cf., Yang and Qiu 2018) and cor=TRUE
implies that the covariance is accommodated and the three-step local smoothing
approach is used to estimate the mean function (cf., Yang and Qiu 2022).
Default is FALSE.
stE
A three-column matrix specifying the spatial locations and times where
we want to calculate the estimate of the mean. Default is NULL, and
stE=st if stE=NULL.
Yang, K. and Qiu, P. (2018). Spatio-Temporal Incidence Rate Data Analysis by
Nonparametric Regression. Statistics in Medicine, 37, 2094-2107.
Yang, K. and Qiu, P. (2022). A Three-Step Local Smoothing Approach for
Estimating the Mean and Covariance Functions of Spatio-Temporal Data.
Annals of the Institute of Statistical Mathematics, 74, 49-68.