The function spte_covest is developed to estimate the spatio-temporal
covariance \(V(t,t';s,s')=\mbox{Cov}(y(t,s),y(t',s'))\) by the weighted
moment estimation procedure (cf., Yang and Qiu 2019). It should be noted that
the estimated covariance from spte_covest may not be positive
semidefinite and thus it may not be a legitimate covariance function. In such
cases, the projection-based modification needs to be used to make it positive
semidefinite (cf., Yang and Qiu 2019).